"use strict";
// Copyright (c) Vidar Tonaas Fauske
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const controls_1 = require("@jupyter-widgets/controls");
const version_1 = require("./version");
const invalidValueClass = 'jpcombo-invalid-value';
class ComboboxModel extends controls_1.TextModel {
    defaults() {
        return Object.assign({}, super.defaults(), { _model_name: ComboboxModel.model_name, _model_module: ComboboxModel.model_module, _model_module_version: ComboboxModel.model_module_version, _view_name: ComboboxModel.view_name, _view_module: ComboboxModel.view_module, _view_module_version: ComboboxModel.view_module_version, options: [], ensure_options: false });
    }
}
ComboboxModel.serializers = Object.assign({}, controls_1.TextModel.serializers);
ComboboxModel.model_name = 'ComboboxModel';
ComboboxModel.model_module = version_1.MODULE_NAME;
ComboboxModel.model_module_version = version_1.MODULE_VERSION;
ComboboxModel.view_name = 'ComboboxView'; // Set to null if no view
ComboboxModel.view_module = version_1.MODULE_NAME; // Set to null if no view
ComboboxModel.view_module_version = version_1.MODULE_VERSION;
exports.ComboboxModel = ComboboxModel;
class ComboboxView extends controls_1.TextView {
    constructor() {
        super(...arguments);
        this.isInitialRender = true;
    }
    render() {
        this.datalist = document.createElement('datalist');
        this.datalist.id = controls_1.uuid();
        super.render();
        this.textbox.setAttribute('list', this.datalist.id);
        this.el.appendChild(this.datalist);
    }
    update(options) {
        super.update(options);
        if (!this.datalist) {
            return;
        }
        const valid = this.isValid(this.model.get('value'));
        this.highlightValidState(valid);
        // Check if we need to update options
        if ((options !== undefined && options.updated_view) || (!this.model.hasChanged('options') &&
            !this.isInitialRender)) {
            // Value update only, keep current options
            return;
        }
        this.isInitialRender = false;
        const opts = this.model.get('options');
        const optLines = opts.map(o => {
            return `<option value="${o}"></option>`;
        });
        this.datalist.innerHTML = optLines.join('\n');
    }
    isValid(value) {
        if (true === this.model.get('ensure_option')) {
            const options = this.model.get('options');
            if (options.indexOf(value) === -1) {
                return false;
            }
        }
        return true;
    }
    /**
     * Handles user input.
     */
    handleChanging(e) {
        const target = e.target;
        const valid = this.isValid(target.value);
        this.highlightValidState(valid);
        if (valid) {
            super.handleChanging(e);
        }
    }
    handleChanged(e) {
        const target = e.target;
        const valid = this.isValid(target.value);
        this.highlightValidState(valid);
        if (valid) {
            super.handleChanged(e);
        }
    }
    highlightValidState(valid) {
        if (valid) {
            this.textbox.classList.remove(invalidValueClass);
        }
        else {
            this.textbox.classList.add(invalidValueClass);
        }
    }
}
exports.ComboboxView = ComboboxView;
//# sourceMappingURL=widget.js.map